@@ -1,5 +1,5 @@
 """Top-level package for startup."""
 
 __author__ = """Robert van Straalen"""
-__email__ = 'robert.vanstraalen@datasciencelab.nl'
-__version__ = '0.1.2'
+__email__ = 'tech@datasciencelab.nl'
+__version__ = '0.1.3'
